**************************
How Nengo GUI's Code Works
**************************

For details on how all the code of Nengo GUI is organised and interacts with
itself, please check out this presentation: `https://docs.google.com/presentation/d/1XtAv3GDW2f7pRjKDJcRmqgwWxSQRXcsDZxUiK4hRrjs/edit?usp=sharing` by Sean Aubin.
